@@ -117,6 +117,14 @@ LDAP *ad_login() {
 		return 0;
 	}
 
+	// disable referrals
+	result=ldap_set_option(ds, LDAP_OPT_REFERRALS, LDAP_OPT_OFF);
+	if(result!=LDAP_OPT_SUCCESS) {
+		snprintf(ad_error_msg, MAX_ERR_LENGTH, "Error in ldap_set_option (referrals=0): %s", ldap_err2string(result));
+		ad_error_code=AD_SERVER_CONNECT_FAILURE;
+		return 0;
+	}
+
 	bindresult=ldap_simple_bind_s(ds, binddn, bindpw);
 	if(bindresult!=LDAP_SUCCESS) {
 		snprintf(ad_error_msg, MAX_ERR_LENGTH, "Error in ldap_bind %s", ldap_err2string(bindresult));
@@ -127,7 +135,10 @@ LDAP *ad_login() {
 
 	if(uri!=NULL) free(uri);
 	if(binddn!=NULL) free(binddn);
-	if(bindpw!=NULL) free(bindpw);
+	if(bindpw!=NULL) {
+		memset(bindpw, 0, sizeof(bindpw));
+		free(bindpw);
+	}
 
 	return ds;
 
